# binaryToDecimal
A package that converts binary form of data to decimal, to contact me use my website https://karthiks-digital-resume-react.netlify.app and send your queries in contact section

Usage:







<img width="338" alt="Screenshot 2023-02-05 at 7 11 01 PM" src="https://user-images.githubusercontent.com/67945756/216822729-664bc7b3-4d1a-40b4-89c7-8b2db72893dd.png">

